# collectors-channel-cli
Built with ❤️ using [Typer](https://typer.tiangolo.com)


## How to use it

Create a properties file at ``$HOME/.collectors/my.properties`` using this as an example: 
```
# MongoDB
MONGO_URL=mongodb+srv://user:password@url/database
```
Or pass ``--props`` to the CLI with the file location.


Check out the project at GitLab: https://gitlab.com/collectors-channel.
